@@ -198,6 +198,26 @@ class View
 		//get active tab
 		$tab = self::getTab($group);
 
+		// If a sub-page of the overview tab
+		$active = strtolower(Request::getVar('active', 'overview'));
+		if ($tab == 'overview' && $tab != $active)
+		{
+			$pageArchive = Archive::getInstance();
+			$pages = $pageArchive->pages('list', array(
+				'gidNumber' => $group->get('gidNumber'),
+				'state'     => array(0,1),
+				'orderby'   => 'lft ASC'
+			));
+
+			// fetch the active page
+			$activePage = Pages::getActivePage($group, $pages);
+
+			if ($activePage)
+			{
+				return $activePage->get('title');
+			}
+		}
+
 		//return title of active tab
 		foreach ($sections as $section)
 		{
@@ -232,7 +252,7 @@ class View
 
 		// pass vars to view
 		$view->group           = $group;
-		$view->user            = User::getRoot();
+		$view->user            = User::getInstance();
 		$view->classOrId       = $classOrId;
 		$view->tab             = self::getTab($group);
 		$view->sections        = self::getSections();
@@ -417,7 +437,7 @@ class View
 
 		// pass vars to view
 		$view->group      = $group;
-		$view->user       = User::getRoot();
+		$view->user       = User::getInstance();
 		$view->classOrId  = $classOrId;
 		$view->logoutLink = $displayLogoutLink;
 
@@ -605,7 +625,7 @@ class View
 		}
 
 		// attach custom error handler
-		set_exception_handler(array('\Components\Groups\Helpers\View', 'handleCustomError'));
+		//set_exception_handler(array('\Components\Groups\Helpers\View', 'handleCustomError'));
 	}
 
 	/**
