@@ -240,7 +240,8 @@ class Profiles extends SiteController
 		$obj['orig'] = true;
 
 		//add back original query
-		array_unshift($json, $obj);
+		// [!] Removing. Seems to confuse people.
+		//array_unshift($json, $obj);
 
 		echo json_encode($json);
 	}
@@ -296,7 +297,7 @@ class Profiles extends SiteController
 					->whereIn('access', User::getAuthorisedViewLevels());
 			}])
 			->whereEquals($a . '.block', 0)
-			->whereEquals($a . '.activation', 1)
+			->where($a . '.activation', '>', 0)
 			->where($a . '.approved', '>', 0);
 
 		// Take filters and apply them to the tasks
@@ -509,7 +510,7 @@ class Profiles extends SiteController
 		// Get record count of all members
 		$stats->total_members = Member::all()
 			->whereEquals('block', 0)
-			->whereEquals('activation', 1)
+			->where('activation', '>', 0)
 			->where('approved', '>', 0)
 			->total();
 
@@ -659,9 +660,11 @@ class Profiles extends SiteController
 			}
 		}
 
-		if ($tab != 'profile' && !in_array($tab, $available))
+		//if ($tab != 'profile' && !in_array($tab, $available))
+		if (!in_array($tab, $available) && isset($available[0]))
 		{
-			$tab = 'profile';
+			//$tab = 'profile';
+			$tab = $available[0];
 		}
 
 		// Get the sections
