@@ -722,13 +722,13 @@ class Register extends SiteController
 					$newUsertype = $db->loadResult();
 				}
 
-				$user->set('username', $xregistration->get('login'));
-				$user->set('name', $xregistration->get('name'));
-				$user->set('givenName', $xregistration->get('givenName'));
-				$user->set('middleName', $xregistration->get('middleName'));
-				$user->set('surname', $xregistration->get('surname'));
-				$user->set('email', $xregistration->get('email'));
-				$user->set('usageAgreement', $xregistration->get('usageAgreement'));
+				$user->set('username', $xregistration->get('login', ''));
+				$user->set('name', $xregistration->get('name', ''));
+				$user->set('givenName', $xregistration->get('givenName', ''));
+				$user->set('middleName', $xregistration->get('middleName', ''));
+				$user->set('surname', $xregistration->get('surname', ''));
+				$user->set('email', $xregistration->get('email', ''));
+				$user->set('usageAgreement', (int)$xregistration->get('usageAgreement', 0));
 				$user->set('sendEmail', -1);
 				if ($xregistration->get('sendEmail') >= 0)
 				{
@@ -813,7 +813,7 @@ class Register extends SiteController
 				else if ($useractivation == 0)
 				{
 					$user->set('activation', 1);
-					$user->set('access', $this->config->get('privacy', 1));
+					$user->set('access', (int)$this->config->get('privacy', 1));
 				}
 
 				$user->set('password', \Hubzero\User\Password::getPasshash($xregistration->get('password')));
@@ -907,6 +907,7 @@ class Register extends SiteController
 					}
 
 					// Notify administration
+					/* Moved to user plugin
 					if ($usersConfig->get('mail_to_admin', 0))
 					{
 						$eview  = new \Hubzero\Mail\View(array(
@@ -944,7 +945,7 @@ class Register extends SiteController
 						{
 							\Log::error('Members admin notification email failed: ' . Lang::txt('Failed to mail %s', $hubMonitorEmail));
 						}
-					}
+					}*/
 
 					// Instantiate a new view
 					$this->view
@@ -1193,7 +1194,7 @@ class Register extends SiteController
 		$xprofile = User::getInstance();
 		$login = $xprofile->get('username');
 		$email = $xprofile->get('email');
-		$email_confirmed = $xprofile->get('emailConfirmed');
+		$email_confirmed = $xprofile->get('activation');
 
 		// Incoming
 		$return = urldecode(Request::getVar('return', '/'));
@@ -1335,10 +1336,11 @@ class Register extends SiteController
 						// Attempt to send a new confirmation code
 						$confirm = \Components\Members\Helpers\Utility::genemailconfirm();
 
-						$xprofile = new \Hubzero\User\Profile();
-						$xprofile->load($login);
-						$xprofile->set('emailConfirmed', $confirm);
-						$xprofile->update();
+						$xprofile = User::getInstance();
+						$xprofile->get('username');
+						$xprofile->get('email');
+						$xprofile->set('activation', $confirm);
+						$xprofile->save();
 
 						$subject  = Config::get('sitename').' '.Lang::txt('COM_MEMBERS_REGISTER_EMAIL_CONFIRMATION');
 
