@@ -38,6 +38,11 @@ use Components\Projects\Models\Orm\Description\Field;
 use Components\Projects\Models\Orm\Description;
 use Components\Projects\Models\Orm\Project as ProjectORM;
 use Exception;
+use Request;
+use Route;
+use User;
+use Lang;
+use App;
 
 require_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'description' . DS . 'field.php';
 require_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'description.php';
@@ -72,6 +77,17 @@ class Setup extends Base
 			return;
 		}
 
+		if (!User::authorise('core.create', $this->_option)
+		 && !User::authorise('core.edit', $this->_option)
+		 && !User::authorise('core.manage', $this->_option))
+		{
+			App::redirect(
+				Route::url('index.php?option=' . $this->_option),
+				Lang::txt('ALERTNOTAUTH'),
+				'warning'
+			);
+		}
+
 		parent::execute();
 	}
 
@@ -832,6 +848,7 @@ class Setup extends Base
 					foreach ($incoming as $key => $value)
 					{
 						$this->model->saveParam($key, $value);
+						$this->model->params->set($key, $value);
 
 						// If grant information changed
 						if ($key == 'grant_status')
