@@ -1193,6 +1193,28 @@ class Sessions extends SiteController
 		// Call the view command
 		$status = $this->middleware($command, $output);
 
+                // If weber_auth is defined, set a cookie for it.
+                if (isset($output->weber_auth))
+                {
+                        $domain = rtrim(Request::base(), '/');
+                        $domain = preg_replace('/^http:\/\//', '', $domain);
+                        $domain = preg_replace('/^https:\/\//', '', $domain);
+                        $name = "weber-auth-" . preg_replace('/\./', '-', $domain);
+                        $secure = true;
+                        $httponly = true;
+                        setcookie($name, $output->weber_auth,
+                                  time()+86400*30, "/", $domain,
+                                  $secure, $httponly);
+                }
+
+                // If this is something other than VNC, such as Jupyter,
+                // redirect to the proxy URL provided.  And we're done.
+                if (isset($output->redirect_url))
+                {
+                        App::Redirect($output->redirect_url);
+                        return; // Do no more after this.
+                }
+
 		if ($app->params->get('vncEncoding',0))
 		{
 			$output->encoding = trim($app->params->get('vncEncoding',''),'"');
