@@ -35,16 +35,13 @@ class Migration20141110143234ComMembers extends Base
 					'unemployed'              => 'Retired / Unemployed'
 				);
 
-				include_once(PATH_CORE . DS . 'components' . DS . 'com_members' . DS . 'tables' . DS . 'organizationtype.php');
-
 				foreach ($types as $alias => $title)
 				{
-					$row = new \Components\Members\Tables\OrganizationType($this->db);
-					$row->type  = $alias;
-					$row->title = $title;
-					$row->store();
+					$query = "INSERT INTO `#__xorganization_types` (`id`, `type`, `title`) VALUES (NULL, " . $this->db->quote($alias) . ",". $this->db->quote($title) . ")";
+					$this->db->setQuery($query);
+					$this->db->query();
 				}
 			}
 		}
 	}
-}
\ No newline at end of file
+}
