@@ -25,7 +25,6 @@
  * HUBzero is a registered trademark of Purdue University.
  *
  * @package   hubzero-cms
- * @author    Alissa Nedossekina <alisa@purdue.edu>
  * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
  * @license   http://opensource.org/licenses/MIT MIT
  */
@@ -34,16 +33,19 @@
 defined('_HZEXEC_') or die();
 
 $this->css();
-
 ?>
-
-<div class="watch<?php echo $this->watched ? ' watching' : ' '; ?>">
-	<span class="pub-info-pop tooltips" title="<?php echo Lang::txt('PLG_PUBLICATIONS_WATCH_TITLE') . ' :: ' . Lang::txt('PLG_PUBLICATIONS_WATCH_EXPLAIN'); ?>">&nbsp;</span>
+<div class="item-watch <?php echo $this->watched ? 'watching' : ''; ?>">
 	<?php if ($this->watched) { ?>
-		<p><?php echo Lang::txt('PLG_PUBLICATIONS_WATCH_WATCHED'); ?> <a href="<?php echo Route::url($this->publication->link() . '&active=watch&action=unsubscribe&confirm=1'); ?>"><?php echo Lang::txt('PLG_PUBLICATIONS_WATCH_UNSUBSCRIBE'); ?></a></p>
+		<p>
+			<a class="btn unsubscribe" href="<?php echo Route::url($this->publication->link() . '&active=watch&confirm=1&action=unsubscribe'); ?>"><?php echo Lang::txt('PLG_PUBLICATIONS_WATCH_UNSUBSCRIBE'); ?></a>
+		</p>
 	<?php } else { ?>
-		<p><?php echo Lang::txt('PLG_PUBLICATIONS_WATCH_WANT_TO_FOLLOW'); ?>
-			<a href="<?php echo Route::url($this->publication->link() . '&active=watch&action=subscribe&confirm=1'); ?>"><?php echo Lang::txt('PLG_PUBLICATIONS_WATCH_SUBSCRIBE'); ?></a>
+		<p>
+			<a class="btn subscribe" href="<?php echo Route::url($this->publication->link() . '&active=watch&confirm=1&action=subscribe'); ?>"><?php echo Lang::txt('PLG_PUBLICATIONS_WATCH_SUBSCRIBE'); ?></a>
 		</p>
 	<?php } ?>
+
+	<p>
+		<?php echo Lang::txt('PLG_PUBLICATIONS_WATCH_EXPLAIN'); ?>
+	</p>
 </div>
\ No newline at end of file
