@@ -40,9 +40,9 @@ defined('_HZEXEC_') or die();
 	<p class="details">
 		<?php echo $this->entry->published('date'); ?>
 		<span>|</span>
-		<?php echo Lang::txt('PLG_TAGS_BLOGS_POSTED_BY', '<cite><a href="' . Route::url('index.php?option=com_members&id=' . $this->entry->get('created_by')) . '">' . $this->escape(stripslashes($this->entry->creator('name'))) . '</a></cite>'); ?>
+		<?php echo Lang::txt('PLG_TAGS_BLOGS_POSTED_BY', '<cite><a href="' . Route::url('index.php?option=com_members&id=' . $this->entry->get('created_by')) . '">' . $this->escape(stripslashes($this->entry->creator()->get('name'))) . '</a></cite>'); ?>
 	</p>
-	<?php if ($content = $this->entry->content('clean', 200)) { ?>
+	<?php if ($content = \Hubzero\Utility\String::truncate(strip_tags($this->entry->content()), 200)) { ?>
 		<p><?php echo $content; ?></p>
 	<?php } ?>
 	<p class="href">
